"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_blockchain_events_subscriptions_e400 import ListBlockchainEventsSubscriptionsE400
globals()['ListBlockchainEventsSubscriptionsE400'] = ListBlockchainEventsSubscriptionsE400
from cryptoapis.model.list_blockchain_events_subscriptions400_response import ListBlockchainEventsSubscriptions400Response


class TestListBlockchainEventsSubscriptions400Response(unittest.TestCase):
    """ListBlockchainEventsSubscriptions400Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListBlockchainEventsSubscriptions400Response(self):
        """Test ListBlockchainEventsSubscriptions400Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListBlockchainEventsSubscriptions400Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
