"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_eip1559_fee_recommendations_e400 import GetEIP1559FeeRecommendationsE400
globals()['GetEIP1559FeeRecommendationsE400'] = GetEIP1559FeeRecommendationsE400
from cryptoapis.model.get_eip1559_fee_recommendations400_response import GetEIP1559FeeRecommendations400Response


class TestGetEIP1559FeeRecommendations400Response(unittest.TestCase):
    """GetEIP1559FeeRecommendations400Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetEIP1559FeeRecommendations400Response(self):
        """Test GetEIP1559FeeRecommendations400Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetEIP1559FeeRecommendations400Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
