"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.address_tokens_transaction_confirmed_data_item_mined_in_block import AddressTokensTransactionConfirmedDataItemMinedInBlock
from cryptoapis.model.address_tokens_transaction_confirmed_each_confirmation_token import AddressTokensTransactionConfirmedEachConfirmationToken
globals()['AddressTokensTransactionConfirmedDataItemMinedInBlock'] = AddressTokensTransactionConfirmedDataItemMinedInBlock
globals()['AddressTokensTransactionConfirmedEachConfirmationToken'] = AddressTokensTransactionConfirmedEachConfirmationToken
from cryptoapis.model.address_tokens_transaction_confirmed_each_confirmation_data_item import AddressTokensTransactionConfirmedEachConfirmationDataItem


class TestAddressTokensTransactionConfirmedEachConfirmationDataItem(unittest.TestCase):
    """AddressTokensTransactionConfirmedEachConfirmationDataItem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAddressTokensTransactionConfirmedEachConfirmationDataItem(self):
        """Test AddressTokensTransactionConfirmedEachConfirmationDataItem"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AddressTokensTransactionConfirmedEachConfirmationDataItem()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
