"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_join_split_inner import GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_output_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_spend_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsb import GetWalletTransactionDetailsByTransactionIDRIBSB
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsbc import GetWalletTransactionDetailsByTransactionIDRIBSBC
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsbsc import GetWalletTransactionDetailsByTransactionIDRIBSBSC
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsd import GetWalletTransactionDetailsByTransactionIDRIBSD
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsd2 import GetWalletTransactionDetailsByTransactionIDRIBSD2
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribse import GetWalletTransactionDetailsByTransactionIDRIBSE
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsec import GetWalletTransactionDetailsByTransactionIDRIBSEC
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsl import GetWalletTransactionDetailsByTransactionIDRIBSL
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsp import GetWalletTransactionDetailsByTransactionIDRIBSP
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsp_gas_price import GetWalletTransactionDetailsByTransactionIDRIBSPGasPrice
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribst import GetWalletTransactionDetailsByTransactionIDRIBST
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsz import GetWalletTransactionDetailsByTransactionIDRIBSZ
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsz_vin_inner import GetWalletTransactionDetailsByTransactionIDRIBSZVinInner
from cryptoapis.model.list_transactions_by_block_height_ribsz_vout_inner import ListTransactionsByBlockHeightRIBSZVoutInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner'] = GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
globals()['GetWalletTransactionDetailsByTransactionIDRIBSB'] = GetWalletTransactionDetailsByTransactionIDRIBSB
globals()['GetWalletTransactionDetailsByTransactionIDRIBSBC'] = GetWalletTransactionDetailsByTransactionIDRIBSBC
globals()['GetWalletTransactionDetailsByTransactionIDRIBSBSC'] = GetWalletTransactionDetailsByTransactionIDRIBSBSC
globals()['GetWalletTransactionDetailsByTransactionIDRIBSD'] = GetWalletTransactionDetailsByTransactionIDRIBSD
globals()['GetWalletTransactionDetailsByTransactionIDRIBSD2'] = GetWalletTransactionDetailsByTransactionIDRIBSD2
globals()['GetWalletTransactionDetailsByTransactionIDRIBSE'] = GetWalletTransactionDetailsByTransactionIDRIBSE
globals()['GetWalletTransactionDetailsByTransactionIDRIBSEC'] = GetWalletTransactionDetailsByTransactionIDRIBSEC
globals()['GetWalletTransactionDetailsByTransactionIDRIBSL'] = GetWalletTransactionDetailsByTransactionIDRIBSL
globals()['GetWalletTransactionDetailsByTransactionIDRIBSP'] = GetWalletTransactionDetailsByTransactionIDRIBSP
globals()['GetWalletTransactionDetailsByTransactionIDRIBSPGasPrice'] = GetWalletTransactionDetailsByTransactionIDRIBSPGasPrice
globals()['GetWalletTransactionDetailsByTransactionIDRIBST'] = GetWalletTransactionDetailsByTransactionIDRIBST
globals()['GetWalletTransactionDetailsByTransactionIDRIBSZ'] = GetWalletTransactionDetailsByTransactionIDRIBSZ
globals()['GetWalletTransactionDetailsByTransactionIDRIBSZVinInner'] = GetWalletTransactionDetailsByTransactionIDRIBSZVinInner
globals()['ListTransactionsByBlockHeightRIBSZVoutInner'] = ListTransactionsByBlockHeightRIBSZVoutInner
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribs import GetWalletTransactionDetailsByTransactionIDRIBS


class TestGetWalletTransactionDetailsByTransactionIDRIBS(unittest.TestCase):
    """GetWalletTransactionDetailsByTransactionIDRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetWalletTransactionDetailsByTransactionIDRIBS(self):
        """Test GetWalletTransactionDetailsByTransactionIDRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetWalletTransactionDetailsByTransactionIDRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
