"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.estimate_gas_limit_e403 import EstimateGasLimitE403
globals()['EstimateGasLimitE403'] = EstimateGasLimitE403
from cryptoapis.model.estimate_gas_limit403_response import EstimateGasLimit403Response


class TestEstimateGasLimit403Response(unittest.TestCase):
    """EstimateGasLimit403Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEstimateGasLimit403Response(self):
        """Test EstimateGasLimit403Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = EstimateGasLimit403Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
