"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_zilliqa_transactions_by_block_height_e401 import ListZilliqaTransactionsByBlockHeightE401
globals()['ListZilliqaTransactionsByBlockHeightE401'] = ListZilliqaTransactionsByBlockHeightE401
from cryptoapis.model.list_zilliqa_transactions_by_block_height401_response import ListZilliqaTransactionsByBlockHeight401Response


class TestListZilliqaTransactionsByBlockHeight401Response(unittest.TestCase):
    """ListZilliqaTransactionsByBlockHeight401Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListZilliqaTransactionsByBlockHeight401Response(self):
        """Test ListZilliqaTransactionsByBlockHeight401Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListZilliqaTransactionsByBlockHeight401Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
