"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsd2_vin_inner import ListUnconfirmedTransactionsByAddressRIBSD2VinInner
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsd2_vout_inner import ListUnconfirmedTransactionsByAddressRIBSD2VoutInner
globals()['ListUnconfirmedTransactionsByAddressRIBSD2VinInner'] = ListUnconfirmedTransactionsByAddressRIBSD2VinInner
globals()['ListUnconfirmedTransactionsByAddressRIBSD2VoutInner'] = ListUnconfirmedTransactionsByAddressRIBSD2VoutInner
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsd2 import ListUnconfirmedTransactionsByAddressRIBSD2


class TestListUnconfirmedTransactionsByAddressRIBSD2(unittest.TestCase):
    """ListUnconfirmedTransactionsByAddressRIBSD2 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListUnconfirmedTransactionsByAddressRIBSD2(self):
        """Test ListUnconfirmedTransactionsByAddressRIBSD2"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListUnconfirmedTransactionsByAddressRIBSD2()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
