"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_block_details_by_block_hash_from_callback_e401 import GetBlockDetailsByBlockHashFromCallbackE401
globals()['GetBlockDetailsByBlockHashFromCallbackE401'] = GetBlockDetailsByBlockHashFromCallbackE401
from cryptoapis.model.get_block_details_by_block_hash_from_callback401_response import GetBlockDetailsByBlockHashFromCallback401Response


class TestGetBlockDetailsByBlockHashFromCallback401Response(unittest.TestCase):
    """GetBlockDetailsByBlockHashFromCallback401Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetBlockDetailsByBlockHashFromCallback401Response(self):
        """Test GetBlockDetailsByBlockHashFromCallback401Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetBlockDetailsByBlockHashFromCallback401Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
