"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_token_details_by_contract_address_e401 import GetTokenDetailsByContractAddressE401
globals()['GetTokenDetailsByContractAddressE401'] = GetTokenDetailsByContractAddressE401
from cryptoapis.model.get_token_details_by_contract_address401_response import GetTokenDetailsByContractAddress401Response


class TestGetTokenDetailsByContractAddress401Response(unittest.TestCase):
    """GetTokenDetailsByContractAddress401Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetTokenDetailsByContractAddress401Response(self):
        """Test GetTokenDetailsByContractAddress401Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetTokenDetailsByContractAddress401Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
