"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_idribsz_vout_inner import GetTransactionDetailsByTransactionIDRIBSZVoutInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_output_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_spend_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
from cryptoapis.model.list_confirmed_transactions_by_address_ribsb import ListConfirmedTransactionsByAddressRIBSB
from cryptoapis.model.list_confirmed_transactions_by_address_ribsbc import ListConfirmedTransactionsByAddressRIBSBC
from cryptoapis.model.list_confirmed_transactions_by_address_ribsbsc import ListConfirmedTransactionsByAddressRIBSBSC
from cryptoapis.model.list_confirmed_transactions_by_address_ribsbsc_gas_price import ListConfirmedTransactionsByAddressRIBSBSCGasPrice
from cryptoapis.model.list_confirmed_transactions_by_address_ribsd import ListConfirmedTransactionsByAddressRIBSD
from cryptoapis.model.list_confirmed_transactions_by_address_ribsd2 import ListConfirmedTransactionsByAddressRIBSD2
from cryptoapis.model.list_confirmed_transactions_by_address_ribse import ListConfirmedTransactionsByAddressRIBSE
from cryptoapis.model.list_confirmed_transactions_by_address_ribsec import ListConfirmedTransactionsByAddressRIBSEC
from cryptoapis.model.list_confirmed_transactions_by_address_ribsl import ListConfirmedTransactionsByAddressRIBSL
from cryptoapis.model.list_confirmed_transactions_by_address_ribsz import ListConfirmedTransactionsByAddressRIBSZ
from cryptoapis.model.list_confirmed_transactions_by_address_ribsz_vin_inner import ListConfirmedTransactionsByAddressRIBSZVinInner
from cryptoapis.model.list_confirmed_transactions_by_address_ribszv_join_split_inner import ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVoutInner'] = GetTransactionDetailsByTransactionIDRIBSZVoutInner
globals()['ListConfirmedTransactionsByAddressRIBSB'] = ListConfirmedTransactionsByAddressRIBSB
globals()['ListConfirmedTransactionsByAddressRIBSBC'] = ListConfirmedTransactionsByAddressRIBSBC
globals()['ListConfirmedTransactionsByAddressRIBSBSC'] = ListConfirmedTransactionsByAddressRIBSBSC
globals()['ListConfirmedTransactionsByAddressRIBSBSCGasPrice'] = ListConfirmedTransactionsByAddressRIBSBSCGasPrice
globals()['ListConfirmedTransactionsByAddressRIBSD'] = ListConfirmedTransactionsByAddressRIBSD
globals()['ListConfirmedTransactionsByAddressRIBSD2'] = ListConfirmedTransactionsByAddressRIBSD2
globals()['ListConfirmedTransactionsByAddressRIBSE'] = ListConfirmedTransactionsByAddressRIBSE
globals()['ListConfirmedTransactionsByAddressRIBSEC'] = ListConfirmedTransactionsByAddressRIBSEC
globals()['ListConfirmedTransactionsByAddressRIBSL'] = ListConfirmedTransactionsByAddressRIBSL
globals()['ListConfirmedTransactionsByAddressRIBSZ'] = ListConfirmedTransactionsByAddressRIBSZ
globals()['ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner'] = ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner
globals()['ListConfirmedTransactionsByAddressRIBSZVinInner'] = ListConfirmedTransactionsByAddressRIBSZVinInner
from cryptoapis.model.list_confirmed_transactions_by_address_ribs import ListConfirmedTransactionsByAddressRIBS


class TestListConfirmedTransactionsByAddressRIBS(unittest.TestCase):
    """ListConfirmedTransactionsByAddressRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListConfirmedTransactionsByAddressRIBS(self):
        """Test ListConfirmedTransactionsByAddressRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListConfirmedTransactionsByAddressRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
