"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_zilliqa_transaction_details_by_transaction_idri_fee import GetZilliqaTransactionDetailsByTransactionIDRIFee
from cryptoapis.model.list_zilliqa_transactions_by_address_ri_recipients_inner import ListZilliqaTransactionsByAddressRIRecipientsInner
from cryptoapis.model.list_zilliqa_transactions_by_address_ri_senders_inner import ListZilliqaTransactionsByAddressRISendersInner
globals()['GetZilliqaTransactionDetailsByTransactionIDRIFee'] = GetZilliqaTransactionDetailsByTransactionIDRIFee
globals()['ListZilliqaTransactionsByAddressRIRecipientsInner'] = ListZilliqaTransactionsByAddressRIRecipientsInner
globals()['ListZilliqaTransactionsByAddressRISendersInner'] = ListZilliqaTransactionsByAddressRISendersInner
from cryptoapis.model.list_zilliqa_transactions_by_address_ri import ListZilliqaTransactionsByAddressRI


class TestListZilliqaTransactionsByAddressRI(unittest.TestCase):
    """ListZilliqaTransactionsByAddressRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListZilliqaTransactionsByAddressRI(self):
        """Test ListZilliqaTransactionsByAddressRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListZilliqaTransactionsByAddressRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
