"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_transactions_by_block_hash_ribsbc_vin_inner import ListTransactionsByBlockHashRIBSBCVinInner
from cryptoapis.model.list_transactions_by_block_hash_ribsbc_vout_inner import ListTransactionsByBlockHashRIBSBCVoutInner
globals()['ListTransactionsByBlockHashRIBSBCVinInner'] = ListTransactionsByBlockHashRIBSBCVinInner
globals()['ListTransactionsByBlockHashRIBSBCVoutInner'] = ListTransactionsByBlockHashRIBSBCVoutInner
from cryptoapis.model.list_transactions_by_block_hash_ribsbc import ListTransactionsByBlockHashRIBSBC


class TestListTransactionsByBlockHashRIBSBC(unittest.TestCase):
    """ListTransactionsByBlockHashRIBSBC unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListTransactionsByBlockHashRIBSBC(self):
        """Test ListTransactionsByBlockHashRIBSBC"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListTransactionsByBlockHashRIBSBC()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
