"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_fee_recommendations_e403 import GetFeeRecommendationsE403
globals()['GetFeeRecommendationsE403'] = GetFeeRecommendationsE403
from cryptoapis.model.get_fee_recommendations403_response import GetFeeRecommendations403Response


class TestGetFeeRecommendations403Response(unittest.TestCase):
    """GetFeeRecommendations403Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetFeeRecommendations403Response(self):
        """Test GetFeeRecommendations403Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetFeeRecommendations403Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
