"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_wallet_asset_details_ri_confirmed_balance import GetWalletAssetDetailsRIConfirmedBalance
from cryptoapis.model.get_wallet_asset_details_ri_fungible_tokens_inner import GetWalletAssetDetailsRIFungibleTokensInner
from cryptoapis.model.get_wallet_asset_details_ri_non_fungible_tokens_inner import GetWalletAssetDetailsRINonFungibleTokensInner
from cryptoapis.model.get_wallet_asset_details_ri_recieved_confirmed_amount import GetWalletAssetDetailsRIRecievedConfirmedAmount
from cryptoapis.model.get_wallet_asset_details_ri_sent_confirmed_amount import GetWalletAssetDetailsRISentConfirmedAmount
globals()['GetWalletAssetDetailsRIConfirmedBalance'] = GetWalletAssetDetailsRIConfirmedBalance
globals()['GetWalletAssetDetailsRIFungibleTokensInner'] = GetWalletAssetDetailsRIFungibleTokensInner
globals()['GetWalletAssetDetailsRINonFungibleTokensInner'] = GetWalletAssetDetailsRINonFungibleTokensInner
globals()['GetWalletAssetDetailsRIRecievedConfirmedAmount'] = GetWalletAssetDetailsRIRecievedConfirmedAmount
globals()['GetWalletAssetDetailsRISentConfirmedAmount'] = GetWalletAssetDetailsRISentConfirmedAmount
from cryptoapis.model.get_wallet_asset_details_ri import GetWalletAssetDetailsRI


class TestGetWalletAssetDetailsRI(unittest.TestCase):
    """GetWalletAssetDetailsRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetWalletAssetDetailsRI(self):
        """Test GetWalletAssetDetailsRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetWalletAssetDetailsRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
