"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsbc_vin_inner import GetWalletTransactionDetailsByTransactionIDRIBSBCVinInner
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsbc_vout_inner import GetWalletTransactionDetailsByTransactionIDRIBSBCVoutInner
globals()['GetWalletTransactionDetailsByTransactionIDRIBSBCVinInner'] = GetWalletTransactionDetailsByTransactionIDRIBSBCVinInner
globals()['GetWalletTransactionDetailsByTransactionIDRIBSBCVoutInner'] = GetWalletTransactionDetailsByTransactionIDRIBSBCVoutInner
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsbc import GetWalletTransactionDetailsByTransactionIDRIBSBC


class TestGetWalletTransactionDetailsByTransactionIDRIBSBC(unittest.TestCase):
    """GetWalletTransactionDetailsByTransactionIDRIBSBC unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetWalletTransactionDetailsByTransactionIDRIBSBC(self):
        """Test GetWalletTransactionDetailsByTransactionIDRIBSBC"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetWalletTransactionDetailsByTransactionIDRIBSBC()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
