"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.create_fungible_token_transaction_request_from_address_without_fee_priority_e401 import CreateFungibleTokenTransactionRequestFromAddressWithoutFeePriorityE401
globals()['CreateFungibleTokenTransactionRequestFromAddressWithoutFeePriorityE401'] = CreateFungibleTokenTransactionRequestFromAddressWithoutFeePriorityE401
from cryptoapis.model.create_fungible_token_transaction_request_from_address_without_fee_priority401_response import CreateFungibleTokenTransactionRequestFromAddressWithoutFeePriority401Response


class TestCreateFungibleTokenTransactionRequestFromAddressWithoutFeePriority401Response(unittest.TestCase):
    """CreateFungibleTokenTransactionRequestFromAddressWithoutFeePriority401Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateFungibleTokenTransactionRequestFromAddressWithoutFeePriority401Response(self):
        """Test CreateFungibleTokenTransactionRequestFromAddressWithoutFeePriority401Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateFungibleTokenTransactionRequestFromAddressWithoutFeePriority401Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
