"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_transactions_by_block_hash_ri_fee import ListTransactionsByBlockHashRIFee
from cryptoapis.model.list_transactions_by_block_hash_ri_recipients_inner import ListTransactionsByBlockHashRIRecipientsInner
from cryptoapis.model.list_transactions_by_block_hash_ri_senders_inner import ListTransactionsByBlockHashRISendersInner
from cryptoapis.model.list_transactions_by_block_hash_ribs import ListTransactionsByBlockHashRIBS
globals()['ListTransactionsByBlockHashRIBS'] = ListTransactionsByBlockHashRIBS
globals()['ListTransactionsByBlockHashRIFee'] = ListTransactionsByBlockHashRIFee
globals()['ListTransactionsByBlockHashRIRecipientsInner'] = ListTransactionsByBlockHashRIRecipientsInner
globals()['ListTransactionsByBlockHashRISendersInner'] = ListTransactionsByBlockHashRISendersInner
from cryptoapis.model.list_transactions_by_block_hash_ri import ListTransactionsByBlockHashRI


class TestListTransactionsByBlockHashRI(unittest.TestCase):
    """ListTransactionsByBlockHashRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListTransactionsByBlockHashRI(self):
        """Test ListTransactionsByBlockHashRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListTransactionsByBlockHashRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
