"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.create_coins_transaction_request_from_address_ri import CreateCoinsTransactionRequestFromAddressRI
globals()['CreateCoinsTransactionRequestFromAddressRI'] = CreateCoinsTransactionRequestFromAddressRI
from cryptoapis.model.create_coins_transaction_request_from_address_r_data import CreateCoinsTransactionRequestFromAddressRData


class TestCreateCoinsTransactionRequestFromAddressRData(unittest.TestCase):
    """CreateCoinsTransactionRequestFromAddressRData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateCoinsTransactionRequestFromAddressRData(self):
        """Test CreateCoinsTransactionRequestFromAddressRData"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateCoinsTransactionRequestFromAddressRData()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
